@@ -11,6 +11,7 @@ import sklearn
 from .plot import Plot
 from .request import Request
 from .mlmodel import MLModel
+from .experiment import Experiment
 from .script import Script
 from .execution import Execution
 from .dataframe_toolkit import DataFrameToolkit
@@ -225,6 +226,16 @@ class WizataDSAPIClient:
                     return pickle.loads(response.content)
                 else:
                     raise self.__raise_error(response)
+            elif isinstance(obj, Experiment):
+                response = requests.request("GET",
+                                            self.__url() + "experiments/" + str(obj.experiment_id) + "/",
+                                            headers=self.__header()
+                                            )
+                if response.status_code == 200:
+                    obj.from_json(response.json())
+                    return obj
+                else:
+                    raise self.__raise_error(response)
             else:
                 raise TypeError("Type not supported.")
 
@@ -244,6 +255,14 @@ class WizataDSAPIClient:
                 return obj.script_id
             else:
                 raise self.__raise_error(response)
+        elif isinstance(obj, Experiment):
+            response = requests.post(self.__url() + "experiments/",
+                                     headers=self.__header(),
+                                     data=json.dumps(obj.to_json()))
+            if response.status_code == 200:
+                return
+            else:
+                raise self.__raise_error(response)
         else:
             raise TypeError("Type not supported.")
 
@@ -262,6 +281,14 @@ class WizataDSAPIClient:
                 return
             else:
                 raise self.__raise_error(response)
+        elif isinstance(obj, Experiment):
+            response = requests.put(self.__url() + "experiments/" + str(obj.experiment_id) + "/",
+                                    headers=self.__header(),
+                                    data=json.dumps(obj.to_json()))
+            if response.status_code == 200:
+                return
+            else:
+                raise self.__raise_error(response)
         else:
             raise TypeError("Type not supported.")
 
@@ -292,6 +319,13 @@ class WizataDSAPIClient:
         :param obj: object to delete including all content
         :return: None
         """
+        if isinstance(obj, Experiment):
+            response = requests.delete(self.__url() + "experiments" + "/" + str(obj.experiment_id) + "/",
+                                       headers=self.__header())
+            if response.status_code == 200:
+                return
+            else:
+                raise self.__raise_error(response)
         if isinstance(obj, Script):
             response = requests.delete(self.__url() + "scripts" + "/" + str(obj.script_id) + "/",
                                        headers=self.__header())
@@ -330,11 +364,11 @@ class WizataDSAPIClient:
                 script=None,
                 ml_model=None,
                 isAnomalyDetection=False,
-                function=None
+                function=None,
+                experiment=None
                 ) -> Execution:
         """
         execute an experimentation on the server.
-
         :param execution: Execution to execute on the server with configuration (Request, Script, ML Model, ...)
         :param request: Request to use to generate a dataframe
         :param dataframe: dataframe to be used as input (pandas or DS API type)
@@ -342,6 +376,7 @@ class WizataDSAPIClient:
         :param ml_model: MLModel to be executed (accept MLModel, ml_model(id) or uuid)
         :param isAnomalyDetection: set to true to execute automatic anomaly detection
         :param function: set to name of a built-in function to execute it
+        :param experiment: ID or experiment to link the execution too
         :return: Execution updated with expected content (Data, Anomalies, Plots, ML Models, ...)
         """
         # Prepare
@@ -372,6 +407,13 @@ class WizataDSAPIClient:
             execution.isAnomalyDetection = True
         if function is not None:
             execution.function = function
+        if experiment is not None:
+            if isinstance(experiment, uuid.UUID):
+                execution.experiment_id = experiment
+            elif isinstance(experiment, str):
+                execution.experiment_id = uuid.UUID(experiment)
+            elif isinstance(experiment, Experiment):
+                execution.experiment_id = experiment.experiment_id
 
         # Execute
         if isinstance(execution, Execution):
